package de.hsrg.gui;

import java.awt.Container;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.SwingUtilities;
import javax.swing.WindowConstants;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

public class HochschuleMain implements ActionListener, ChangeListener { 
	public static final int WIDTH = 360, HEIGHT = 180, INSET = 60;	
	public static final String TITLE = "Hochschule Regensburg";
	private int width, height, inset;
	private Dashboard controls;
	private BlueCube cube;  

	public HochschuleMain(Container content)  {
		inset = INSET;  width = WIDTH;  height = HEIGHT;
		cube = new BlueCube(width, height);
    	controls = new Dashboard(content, cube, this, this);
    	controls.setup( );
	}
	
	public void actionPerformed(ActionEvent pushed) {
		JButton button = (JButton)pushed.getSource( );
		String label = button.getText( );
		if (label.equals(Dashboard.START))  {
			button.setText(Dashboard.STOP);
			cube.resumeRotation( );
		}  else if (label.equals(Dashboard.STOP))  {
			button.setText(Dashboard.START);
			cube.stopRotation( );
		}  else if (label.equals(Dashboard.RESET))  {
			cube.reset( );
		}  else  // Controls.QUIT
			System.exit(0);
	}
	
	public void stateChanged(ChangeEvent sliding) {
		cube.setVelocity(controls.getVelocity( ));
	}	
	
    public static void main(String[] args) {	
        SwingUtilities.invokeLater(new Runnable() {
            public void run( ) {
            	JFrame frame = new JFrame(TITLE);
            	Container content =  frame.getContentPane( );
            	HochschuleMain rotation = new HochschuleMain(content);
                frame.setSize( rotation.width + rotation.inset, 
                		       rotation.height + 3 * rotation.inset );
                frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
                frame.setLocationByPlatform(true);
                new Thread(rotation.cube).start();    
                rotation.cube.stopRotation( );
                frame.setVisible(true);               
            }
        });
    }
}
